# Py-HCL
[![Build Status](https://travis-ci.com/scutdig/pyHCL.svg?branch=master)](https://travis-ci.com/scutdig/pyHCL)
[![codecov](https://codecov.io/gh/scutdig/pyHCL/branch/master/graph/badge.svg)](https://codecov.io/gh/scutdig/pyHCL)

A Hardware Construct Language
